==> managedblockchain-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/managedblockchain/CfnMemberProps.java <==
package software.amazon.awscdk.services.managedblockchain;

/**
 * Properties for defining a `AWS::ManagedBlockchain::Member`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:17:29.347Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnMemberProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ManagedBlockchain::Member.MemberConfiguration`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-memberconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getMemberConfiguration();

    /**
     * `AWS::ManagedBlockchain::Member.InvitationId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-invitationid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getInvitationId();

    /**
     * `AWS::ManagedBlockchain::Member.NetworkConfiguration`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getNetworkConfiguration();

    /**
     * `AWS::ManagedBlockchain::Member.NetworkId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getNetworkId();

    /**
     * @return a {@link Builder} of {@link CfnMemberProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnMemberProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object memberConfiguration;
        private java.lang.String invitationId;
        private java.lang.Object networkConfiguration;
        private java.lang.String networkId;

        /**
         * Sets the value of MemberConfiguration
         * @param memberConfiguration `AWS::ManagedBlockchain::Member.MemberConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder memberConfiguration(software.amazon.awscdk.services.managedblockchain.CfnMember.MemberConfigurationProperty memberConfiguration) {
            this.memberConfiguration = memberConfiguration;
            return this;
        }

        /**
         * Sets the value of MemberConfiguration
         * @param memberConfiguration `AWS::ManagedBlockchain::Member.MemberConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder memberConfiguration(software.amazon.awscdk.core.IResolvable memberConfiguration) {
            this.memberConfiguration = memberConfiguration;
            return this;
        }

        /**
         * Sets the value of InvitationId
         * @param invitationId `AWS::ManagedBlockchain::Member.InvitationId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder invitationId(java.lang.String invitationId) {
            this.invitationId = invitationId;
            return this;
        }

        /**
         * Sets the value of NetworkConfiguration
         * @param networkConfiguration `AWS::ManagedBlockchain::Member.NetworkConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkConfiguration(software.amazon.awscdk.core.IResolvable networkConfiguration) {
            this.networkConfiguration = networkConfiguration;
            return this;
        }

        /**
         * Sets the value of NetworkConfiguration
         * @param networkConfiguration `AWS::ManagedBlockchain::Member.NetworkConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkConfiguration(software.amazon.awscdk.services.managedblockchain.CfnMember.NetworkConfigurationProperty networkConfiguration) {
            this.networkConfiguration = networkConfiguration;
            return this;
        }

        /**
         * Sets the value of NetworkId
         * @param networkId `AWS::ManagedBlockchain::Member.NetworkId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkId(java.lang.String networkId) {
            this.networkId = networkId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnMemberProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnMemberProps build() {
            return new Jsii$Proxy(memberConfiguration, invitationId, networkConfiguration, networkId);
        }
    }

    /**
     * An implementation for {@link CfnMemberProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnMemberProps {
        private final java.lang.Object memberConfiguration;
        private final java.lang.String invitationId;
        private final java.lang.Object networkConfiguration;
        private final java.lang.String networkId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.memberConfiguration = this.jsiiGet("memberConfiguration", java.lang.Object.class);
            this.invitationId = this.jsiiGet("invitationId", java.lang.String.class);
            this.networkConfiguration = this.jsiiGet("networkConfiguration", java.lang.Object.class);
            this.networkId = this.jsiiGet("networkId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Object memberConfiguration, java.lang.String invitationId, java.lang.Object networkConfiguration, java.lang.String networkId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.memberConfiguration = java.util.Objects.requireNonNull(memberConfiguration, "memberConfiguration is required");
            this.invitationId = invitationId;
            this.networkConfiguration = networkConfiguration;
            this.networkId = networkId;
        }

        @Override
        public java.lang.Object getMemberConfiguration() {
            return this.memberConfiguration;
        }

        @Override
        public java.lang.String getInvitationId() {
            return this.invitationId;
        }

        @Override
        public java.lang.Object getNetworkConfiguration() {
            return this.networkConfiguration;
        }

        @Override
        public java.lang.String getNetworkId() {
            return this.networkId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("memberConfiguration", om.valueToTree(this.getMemberConfiguration()));
            if (this.getInvitationId() != null) {
                obj.set("invitationId", om.valueToTree(this.getInvitationId()));
            }
            if (this.getNetworkConfiguration() != null) {
                obj.set("networkConfiguration", om.valueToTree(this.getNetworkConfiguration()));
            }
            if (this.getNetworkId() != null) {
                obj.set("networkId", om.valueToTree(this.getNetworkId()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnMemberProps.Jsii$Proxy that = (CfnMemberProps.Jsii$Proxy) o;

            if (!memberConfiguration.equals(that.memberConfiguration)) return false;
            if (this.invitationId != null ? !this.invitationId.equals(that.invitationId) : that.invitationId != null) return false;
            if (this.networkConfiguration != null ? !this.networkConfiguration.equals(that.networkConfiguration) : that.networkConfiguration != null) return false;
            return this.networkId != null ? this.networkId.equals(that.networkId) : that.networkId == null;
        }

        @Override
        public int hashCode() {
            int result = this.memberConfiguration.hashCode();
            result = 31 * result + (this.invitationId != null ? this.invitationId.hashCode() : 0);
            result = 31 * result + (this.networkConfiguration != null ? this.networkConfiguration.hashCode() : 0);
            result = 31 * result + (this.networkId != null ? this.networkId.hashCode() : 0);
            return result;
        }
    }
}

==> managedblockchain-1.16.2.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/managedblockchain/CfnMemberProps.java <==
package software.amazon.awscdk.services.managedblockchain;

/**
 * Properties for defining a `AWS::ManagedBlockchain::Member`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.4 (build 96d89e1)", date = "2019-11-12T11:54:40.611Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.managedblockchain.$Module.class, fqn = "@aws-cdk/aws-managedblockchain.CfnMemberProps")
@software.amazon.jsii.Jsii.Proxy(CfnMemberProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnMemberProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ManagedBlockchain::Member.MemberConfiguration`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-memberconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getMemberConfiguration();

    /**
     * `AWS::ManagedBlockchain::Member.InvitationId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-invitationid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getInvitationId() {
        return null;
    }

    /**
     * `AWS::ManagedBlockchain::Member.NetworkConfiguration`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkconfiguration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getNetworkConfiguration() {
        return null;
    }

    /**
     * `AWS::ManagedBlockchain::Member.NetworkId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-managedblockchain-member.html#cfn-managedblockchain-member-networkid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getNetworkId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnMemberProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnMemberProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object memberConfiguration;
        private java.lang.String invitationId;
        private java.lang.Object networkConfiguration;
        private java.lang.String networkId;

        /**
         * Sets the value of MemberConfiguration
         * @param memberConfiguration `AWS::ManagedBlockchain::Member.MemberConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder memberConfiguration(software.amazon.awscdk.services.managedblockchain.CfnMember.MemberConfigurationProperty memberConfiguration) {
            this.memberConfiguration = memberConfiguration;
            return this;
        }

        /**
         * Sets the value of MemberConfiguration
         * @param memberConfiguration `AWS::ManagedBlockchain::Member.MemberConfiguration`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder memberConfiguration(software.amazon.awscdk.core.IResolvable memberConfiguration) {
            this.memberConfiguration = memberConfiguration;
            return this;
        }

        /**
         * Sets the value of InvitationId
         * @param invitationId `AWS::ManagedBlockchain::Member.InvitationId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder invitationId(java.lang.String invitationId) {
            this.invitationId = invitationId;
            return this;
        }

        /**
         * Sets the value of NetworkConfiguration
         * @param networkConfiguration `AWS::ManagedBlockchain::Member.NetworkConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkConfiguration(software.amazon.awscdk.core.IResolvable networkConfiguration) {
            this.networkConfiguration = networkConfiguration;
            return this;
        }

        /**
         * Sets the value of NetworkConfiguration
         * @param networkConfiguration `AWS::ManagedBlockchain::Member.NetworkConfiguration`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkConfiguration(software.amazon.awscdk.services.managedblockchain.CfnMember.NetworkConfigurationProperty networkConfiguration) {
            this.networkConfiguration = networkConfiguration;
            return this;
        }

        /**
         * Sets the value of NetworkId
         * @param networkId `AWS::ManagedBlockchain::Member.NetworkId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder networkId(java.lang.String networkId) {
            this.networkId = networkId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnMemberProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnMemberProps build() {
            return new Jsii$Proxy(memberConfiguration, invitationId, networkConfiguration, networkId);
        }
    }

    /**
     * An implementation for {@link CfnMemberProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnMemberProps {
        private final java.lang.Object memberConfiguration;
        private final java.lang.String invitationId;
        private final java.lang.Object networkConfiguration;
        private final java.lang.String networkId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.memberConfiguration = this.jsiiGet("memberConfiguration", java.lang.Object.class);
            this.invitationId = this.jsiiGet("invitationId", java.lang.String.class);
            this.networkConfiguration = this.jsiiGet("networkConfiguration", java.lang.Object.class);
            this.networkId = this.jsiiGet("networkId", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object memberConfiguration, final java.lang.String invitationId, final java.lang.Object networkConfiguration, final java.lang.String networkId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.memberConfiguration = java.util.Objects.requireNonNull(memberConfiguration, "memberConfiguration is required");
            this.invitationId = invitationId;
            this.networkConfiguration = networkConfiguration;
            this.networkId = networkId;
        }

        @Override
        public java.lang.Object getMemberConfiguration() {
            return this.memberConfiguration;
        }

        @Override
        public java.lang.String getInvitationId() {
            return this.invitationId;
        }

        @Override
        public java.lang.Object getNetworkConfiguration() {
            return this.networkConfiguration;
        }

        @Override
        public java.lang.String getNetworkId() {
            return this.networkId;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("memberConfiguration", om.valueToTree(this.getMemberConfiguration()));
            if (this.getInvitationId() != null) {
                data.set("invitationId", om.valueToTree(this.getInvitationId()));
            }
            if (this.getNetworkConfiguration() != null) {
                data.set("networkConfiguration", om.valueToTree(this.getNetworkConfiguration()));
            }
            if (this.getNetworkId() != null) {
                data.set("networkId", om.valueToTree(this.getNetworkId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-managedblockchain.CfnMemberProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnMemberProps.Jsii$Proxy that = (CfnMemberProps.Jsii$Proxy) o;

            if (!memberConfiguration.equals(that.memberConfiguration)) return false;
            if (this.invitationId != null ? !this.invitationId.equals(that.invitationId) : that.invitationId != null) return false;
            if (this.networkConfiguration != null ? !this.networkConfiguration.equals(that.networkConfiguration) : that.networkConfiguration != null) return false;
            return this.networkId != null ? this.networkId.equals(that.networkId) : that.networkId == null;
        }

        @Override
        public int hashCode() {
            int result = this.memberConfiguration.hashCode();
            result = 31 * result + (this.invitationId != null ? this.invitationId.hashCode() : 0);
            result = 31 * result + (this.networkConfiguration != null ? this.networkConfiguration.hashCode() : 0);
            result = 31 * result + (this.networkId != null ? this.networkId.hashCode() : 0);
            return result;
        }
    }
}
